@@ -1504,12 +1504,15 @@ class TestXRImage(unittest.TestCase):
         # L -> LA (int)
         with dask.config.set(scheduler=CustomScheduler(max_computes=1)):
             img = xrimage.XRImage((dataset1 * 150).astype(np.uint8))
+            img.data.attrs['_FillValue'] = 0  # set fill value
             img = img.convert('LA')
             self.assertTrue(np.issubdtype(img.data.dtype, np.integer))
             self.assertTrue(img.mode == 'LA')
             self.assertTrue(len(img.data.coords['bands']) == 2)
-            # make sure the alpha band is all opaque
-            np.testing.assert_allclose(img.data.sel(bands='A'), 255)
+            # make sure the alpha band is all opaque except the first pixel
+            alpha = img.data.sel(bands='A').values.ravel()
+            np.testing.assert_allclose(alpha[0], 0)
+            np.testing.assert_allclose(alpha[1:], 255)
 
         # L -> LA (float)
         with dask.config.set(scheduler=CustomScheduler(max_computes=1)):
@@ -1778,11 +1781,77 @@ class TestXRImage(unittest.TestCase):
         self.assertTupleEqual((1, 5, 15), values.shape)
         self.assertTupleEqual((2, 4), bw.colors.shape)
 
+    def test_stack(self):
+
+        import xarray as xr
+        from trollimage import xrimage
+
+        # background image
+        arr1 = np.zeros((2, 2))
+        data1 = xr.DataArray(arr1, dims=['y', 'x'])
+        bkg = xrimage.XRImage(data1)
+
+        # image to be stacked
+        arr2 = np.full((2, 2), np.nan)
+        arr2[0] = 1
+        data2 = xr.DataArray(arr2, dims=['y', 'x'])
+        img = xrimage.XRImage(data2)
+
+        # expected result
+        arr3 = arr1.copy()
+        arr3[0] = 1
+        data3 = xr.DataArray(arr3, dims=['y', 'x'])
+        res = xrimage.XRImage(data3)
+
+        # stack image over the background
+        bkg.stack(img)
+
+        # check result
+        np.testing.assert_allclose(bkg.data, res.data, rtol=1e-05)
+
     def test_merge(self):
         pass
 
     def test_blend(self):
-        pass
+        import xarray as xr
+        from trollimage import xrimage
+
+        core1 = np.arange(75).reshape(5, 5, 3) / 75.0
+        alpha1 = np.linspace(0, 1, 25).reshape(5, 5, 1)
+        arr1 = np.concatenate([core1, alpha1], 2)
+        data1 = xr.DataArray(arr1, dims=['y', 'x', 'bands'],
+                             coords={'bands': ['R', 'G', 'B', 'A']})
+        img1 = xrimage.XRImage(data1)
+
+        core2 = np.arange(75, 0, -1).reshape(5, 5, 3) / 75.0
+        alpha2 = np.linspace(1, 0, 25).reshape(5, 5, 1)
+        arr2 = np.concatenate([core2, alpha2], 2)
+        data2 = xr.DataArray(arr2, dims=['y', 'x', 'bands'],
+                             coords={'bands': ['R', 'G', 'B', 'A']})
+        img2 = xrimage.XRImage(data2)
+
+        img3 = img1.blend(img2)
+
+        np.testing.assert_allclose(
+                (alpha1 + alpha2 * (1 - alpha1)).squeeze(),
+                img3.data.sel(bands="A"))
+
+        np.testing.assert_allclose(
+            img3.data.sel(bands="R").values,
+            np.array(
+                [[1.,           0.95833635, 0.9136842,  0.8666667,  0.8180645],
+                 [0.768815,     0.72,       0.6728228,  0.62857145, 0.5885714],
+                 [0.55412847,   0.5264665,  0.50666666, 0.495612,   0.49394494],
+                 [0.5020408,    0.52,       0.5476586,  0.5846154,  0.63027024],
+                 [0.683871,     0.7445614,  0.81142855, 0.8835443,  0.96]]))
+
+        with self.assertRaises(TypeError):
+            img1.blend("Salekhard")
+
+        wrongimg = xrimage.XRImage(
+                xr.DataArray(np.zeros((0, 0)), dims=("y", "x")))
+        with self.assertRaises(ValueError):
+            img1.blend(wrongimg)
 
     def test_replace_luminance(self):
         pass
