@@ -449,11 +449,15 @@ class XRImage(object):
 
         If ``data`` is an integer type then the alpha band will be scaled
         to use the smallest (min) value as fully transparent and the largest
-        (max) value as fully opaque. For float types the alpha band spans
-        0 to 1.
+        (max) value as fully opaque. If a `_FillValue` attribute is found for
+        integer type data then it is used to identify null values in the data.
+        Otherwise xarray's `isnull` is used.
+
+        For float types the alpha band spans 0 to 1.
 
         """
-        null_mask = alpha if alpha is not None else self._create_alpha(data)
+        fill_value = data.attrs.get('_FillValue', None)  # integer fill value
+        null_mask = alpha if alpha is not None else self._create_alpha(data, fill_value)
         # if we are using integer data, then alpha needs to be min-int to max-int
         # otherwise for floats we want 0 to 1
         if np.issubdtype(data.dtype, np.integer):
@@ -914,6 +918,16 @@ class XRImage(object):
         self.data = self.data * scale + offset
         self.data.attrs = attrs
 
+    def stack(self, img):
+        """Stack the provided image on top of the current image.
+        """
+        # TODO: Conversions between different modes with notification
+        # to the user, i.e. proper logging
+        if self.mode != img.mode:
+            raise NotImplementedError("Cannot stack images of different modes.")
+
+        self.data = self.data.where(img.data.isnull(), img.data)
+
     def merge(self, img):
         """Use the provided image as background for the current *img* image,
         that is if the current image has missing data.
@@ -937,6 +951,13 @@ class XRImage(object):
             self.channels[i].mask = np.logical_and(selfmask,
                                                    img.channels[i].mask)
 
+    @staticmethod
+    def _colorize(l_data, colormap):
+        # 'l_data' is (1, rows, cols)
+        # 'channels' will be a list of 3 (RGB) or 4 (RGBA) arrays
+        channels = colormap.colorize(l_data)
+        return np.concatenate(channels, axis=0)
+
     def colorize(self, colormap):
         """Colorize the current image using `colormap`.
 
@@ -955,14 +976,7 @@ class XRImage(object):
             alpha = None
 
         l_data = self.data.sel(bands=['L'])
-
-        def _colorize(l_data, colormap):
-            # 'l_data' is (1, rows, cols)
-            # 'channels' will be a list of 3 (RGB) or 4 (RGBA) arrays
-            channels = colormap.colorize(l_data)
-            return np.concatenate(channels, axis=0)
-
-        new_data = l_data.data.map_blocks(_colorize, colormap,
+        new_data = l_data.data.map_blocks(self._colorize, colormap,
                                           chunks=(colormap.colors.shape[1],) + l_data.data.chunks[1:],
                                           dtype=np.float64)
 
@@ -981,6 +995,12 @@ class XRImage(object):
         dims = self.data.dims
         self.data = xr.DataArray(new_data, coords=coords, attrs=attrs, dims=dims)
 
+    @staticmethod
+    def _palettize(data, colormap):
+        """Helper for dask-friendly palettize operation."""
+        # returns data and palette, only need data
+        return colormap.palettize(data)[0]
+
     def palettize(self, colormap):
         """Palettize the current image using `colormap`.
 
@@ -994,12 +1014,7 @@ class XRImage(object):
             raise ValueError("Image should be grayscale to colorize")
 
         l_data = self.data.sel(bands=['L'])
-
-        def _palettize(data):
-            # returns data and palette, only need data
-            return colormap.palettize(data)[0]
-
-        new_data = l_data.data.map_blocks(_palettize, dtype=l_data.dtype)
+        new_data = l_data.data.map_blocks(self._palettize, colormap, dtype=l_data.dtype)
         self.palette = tuple(colormap.colors)
 
         if self.mode == "L":
@@ -1011,22 +1026,61 @@ class XRImage(object):
         self.data.data = new_data
         self.data.coords['bands'] = list(mode)
 
-    def blend(self, other):
-        """Alpha blend *other* on top of the current image."""
-        raise NotImplementedError("This method has not be implemented for "
-                                  "xarray support.")
+    def blend(self, src):
+        r"""Alpha blend *src* on top of the current image.
 
-        if self.mode != "RGBA" or other.mode != "RGBA":
-            raise ValueError("Images must be in RGBA")
-        src = other
-        dst = self
-        outa = src.channels[3] + dst.channels[3] * (1 - src.channels[3])
-        for i in range(3):
-            dst.channels[i] = (src.channels[i] * src.channels[3] +
-                               dst.channels[i] * dst.channels[3] *
-                               (1 - src.channels[3])) / outa
-            dst.channels[i][outa == 0] = 0
-        dst.channels[3] = outa
+        Perform `alpha blending`_ of *src* on top of the current image.
+        Alpha blending is defined as:
+
+        .. math::
+
+           \begin{cases}
+            \mathrm{out}_A =
+             \mathrm{src}_A + \mathrm{dst}_A (1 - \mathrm{src}_A) \\
+            \mathrm{out}_{RGB} =
+             \bigl(\mathrm{src}_{RGB}\mathrm{src}_A
+                 + \mathrm{dst}_{RGB} \mathrm{dst}_A
+                   \left(1 - \mathrm{src}_A \right) \bigr)
+             \div \mathrm{out}_A \\
+            \mathrm{out}_A = 0 \Rightarrow \mathrm{out}_{RGB} = 0
+           \end{cases}
+
+        Both images must have mode ``"RGBA"``.
+
+        Args:
+            src (:class:`XRImage` with mode ``"RGBA"``)
+                Image to be blended on top of current image.
+
+        .. _alpha blending: https://en.wikipedia.org/w/index.php?title=Alpha_compositing&oldid=891033105#Alpha_blending
+
+        Returns
+            XRImage with mode "RGBA", blended as described above
+
+        """
+        # NB: docstring maths copy-pasta from enwiki
+
+        if self.mode != "RGBA":
+            raise ValueError(
+                    "Expected self.mode='RGBA', got {md!s}".format(
+                        md=self.mode))
+        elif not isinstance(src, XRImage):
+            raise TypeError("Expected XRImage, got {tp!s}".format(
+                tp=type(src)))
+        elif src.mode != "RGBA":
+            raise ValueError("Expected src.mode='RGBA', got {sm!s}".format(
+                sm=src.mode))
+
+        srca = src.data.sel(bands="A")
+        dsta = self.data.sel(bands="A")
+        outa = srca + dsta * (1-srca)
+        bi = {"bands": ["R", "G", "B"]}
+        rgb = ((src.data.loc[bi] * srca
+               + self.data.loc[bi] * dsta * (1-srca))
+               / outa).where(outa != 0, 0)
+        return self.__class__(
+                xr.concat(
+                    [rgb, outa.expand_dims("bands")],
+                    dim="bands"))
 
     def show(self):
         """Display the image on screen."""
